Package: quickcode
Type: Package
Title: Quick and Essential 'R' Tricks for Better Scripts
Version: 1.2.0
Authors@R: c(
    person("Obinna", "Obianom", email = "idonshayo@gmail.com", role = c("aut", "cre")),
    person("Brice", "Richard", email = "wem3mew@msn.com", role = "aut")
    )
Maintainer: Obinna Obianom <idonshayo@gmail.com>
Description: The NOT functions, 'R' tricks and a compilation of some simple quick plus often used 'R' codes to improve your scripts. Improve the quality and reproducibility of 'R' scripts.
License: MIT + file LICENSE
URL: https://quickcode.rpkg.net
BugReports: https://github.com/oobianom/quickcode/issues
Depends: R (> 3.6)
Imports: utils, grDevices, stats, rstudioapi, tools, fitdistrplus
Suggests: rmarkdown, knitr, qpdf, testthat
Encoding: UTF-8
VignetteBuilder: knitr
Language: en-US
RoxygenNote: 7.3.2
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-08-26 16:26:24 UTC; askph
Author: Obinna Obianom [aut, cre],
  Brice Richard [aut]
Repository: CRAN
Date/Publication: 2026-08-26 17:00:02 UTC
