# Generated by roxygen2: do not edit by hand

export("%.%")
export("%eo%")
export("%match%")
export("%nin%")
export("%or%")
export(add.header)
export(add.sect.comment)
export(add.snippet.clear)
export(add_key)
export(ai.duplicate)
export(archivedPkg)
export(as.boolean)
export(bionic_txt)
export(cat_to_num)
export(cat_to_num2)
export(chain_func)
export(chain_sep)
export(clean)
export(clean_file)
export(clear)
export(cols.rep)
export(compHist)
export(const)
export(create_shape)
export(data_pop)
export(data_pop_filter)
export(data_push)
export(data_rep)
export(data_shuffle)
export(date1to3)
export(date3to1)
export(detect_outlier)
export(detect_outlier2)
export(duplicate)
export(error.out)
export(extract_IP)
export(extract_comment)
export(fAddDate)
export(find_packages)
export(from_tensor_slices)
export(geo.cv)
export(geo.mean)
export(geo.sd)
export(getDate)
export(getDistribution)
export(getGitRepoChange)
export(getGitRepoStart)
export(getWeekSeq)
export(get_func_def)
export(has.error)
export(header.rmd)
export(in.range)
export(inc)
export(indexed)
export(init)
export(insertInText)
export(iqr_outlier)
export(is.Date)
export(is.cauchy)
export(is.decreasing)
export(is.empty)
export(is.gamma)
export(is.image)
export(is.increasing)
export(is.leap)
export(is.logistic)
export(is.lognormal)
export(is.normal)
export(is.poisson)
export(is.uniform)
export(is.weibull)
export(lastwd)
export(learn_rate_scheduler)
export(libraryAll)
export(list_push)
export(list_shuffle)
export(make_dosing_df)
export(math.mm)
export(math.qt)
export(minus)
export(mix.color)
export(mix.cols.btw)
export(mode.calc)
export(multihead_att)
export(mutate_filter)
export(na.cumsum)
export(ndecimal)
export(newSuperVar)
export(nonmem_scaling)
export(normalize.vector)
export(not.Date)
export(not.data)
export(not.duplicated)
export(not.empty)
export(not.environment)
export(not.exists)
export(not.image)
export(not.inherits)
export(not.integer)
export(not.logical)
export(not.na)
export(not.null)
export(not.numeric)
export(not.vector)
export(number)
export(or)
export(pairDist)
export(percent_match)
export(plus)
export(rDecomPkg)
export(randString)
export(rcolorconst)
export(read.csv.print)
export(read.table.print)
export(refresh)
export(remove_comment)
export(remove_content_in_quotes)
export(rows.rep)
export(sample_by_column)
export(setDisAlpha)
export(setOnce)
export(sort_file_type)
export(sort_length)
export(sound_match)
export(strsplit.bool)
export(strsplit.num)
export(sub.range)
export(summarize.envobj)
export(switch_cols)
export(switch_rows)
export(track_func)
export(trim.file)
export(unique_len)
export(unsetDisAlpha)
export(vector_pop)
export(vector_push)
export(vector_shuffle)
export(yesNoBool)
export(zscore)
export(zscoreGrowthCurve)
export(zscore_outlier)
export(zscore_outlier2)
importFrom(grDevices,col2rgb)
importFrom(grDevices,graphics.off)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,boxplot)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rug)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(stats,approx)
importFrom(stats,density)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,adist)
importFrom(utils,read.csv)
importFrom(utils,read.table)
