% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nm_scale.R
\name{print.nonmem_scaling}
\alias{print.nonmem_scaling}
\title{Print method for s1_scaling objects}
\usage{
\method{print}{nonmem_scaling}(x, ...)
}
\arguments{
\item{x}{An object of class \code{s1_scaling}.}

\item{...}{Additional arguments (ignored).}
}
\description{
Print method for s1_scaling objects
}
